summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoDetailsPane.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kofficecore/KoDetailsPane.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoDetailsPane.h')
-rw-r--r--lib/kofficecore/KoDetailsPane.h48
1 files changed, 25 insertions, 23 deletions
diff --git a/lib/kofficecore/KoDetailsPane.h b/lib/kofficecore/KoDetailsPane.h
index 96a92b98..bee6f14a 100644
--- a/lib/kofficecore/KoDetailsPane.h
+++ b/lib/kofficecore/KoDetailsPane.h
@@ -26,11 +26,11 @@
class KoTemplateGroup;
class KoTemplate;
class KInstance;
-class QListViewItem;
+class TQListViewItem;
class KoRecentDocumentsPanePrivate;
class KoRichTextListItemPrivate;
class KFileItem;
-class QPixmap;
+class TQPixmap;
namespace KIO {
class Job;
@@ -40,46 +40,47 @@ class KoTemplatesPanePrivate;
/**
* This widget is the right-side part of the template opening widget.
* The parent widget is initial widget in the document space of each KOffice component.
* This widget shows a list of templates and can show their details or open it.
*/
class KoTemplatesPane : public KoDetailsPaneBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
* @param parent the parent widget
* @param instance the instance object for the app
* @param group the group of templates this widget will show.
* @param defaultTemplate pointer to the default template. Used to select a
* template when none has been selected before.
*/
- KoTemplatesPane(QWidget* parent, KInstance* instance,
+ KoTemplatesPane(TQWidget* tqparent, KInstance* instance,
KoTemplateGroup* group, KoTemplate* defaultTemplate);
~KoTemplatesPane();
/// Returns true if a template in this group was the last one selected
bool isSelected();
- virtual bool eventFilter(QObject* watched, QEvent* e);
+ virtual bool eventFilter(TQObject* watched, TQEvent* e);
signals:
- void openTemplate(const QString&);
+ void openTemplate(const TQString&);
/// Emited when the always use checkbox is selected
- void alwaysUseChanged(KoTemplatesPane* sender, const QString& alwaysUse);
+ void alwaysUseChanged(KoTemplatesPane* sender, const TQString& alwaysUse);
- void splitterResized(KoDetailsPaneBase* sender, const QValueList<int>& sizes);
+ void splitterResized(KoDetailsPaneBase* sender, const TQValueList<int>& sizes);
public slots:
- void resizeSplitter(KoDetailsPaneBase* sender, const QValueList<int>& sizes);
+ void resizeSplitter(KoDetailsPaneBase* sender, const TQValueList<int>& sizes);
protected slots:
- void selectionChanged(QListViewItem* item);
+ void selectionChanged(TQListViewItem* item);
void openTemplate();
- void openTemplate(QListViewItem* item);
+ void openTemplate(TQListViewItem* item);
void alwaysUseClicked();
- void changeAlwaysUseTemplate(KoTemplatesPane* sender, const QString& alwaysUse);
+ void changeAlwaysUseTemplate(KoTemplatesPane* sender, const TQString& alwaysUse);
void changePalette();
@@ -90,38 +91,39 @@ class KoTemplatesPane : public KoDetailsPaneBase
/**
* This widget is the recent doc part of the template opening widget.
* The parent widget is initial widget in the document space of each KOffice component.
* This widget shows a list of recent documents and can show their details or open it.
*/
class KoRecentDocumentsPane : public KoDetailsPaneBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
* @param parent the parent widget
* @param instance the instance object for the app
*/
- KoRecentDocumentsPane(QWidget* parent, KInstance* instance);
+ KoRecentDocumentsPane(TQWidget* tqparent, KInstance* instance);
~KoRecentDocumentsPane();
- virtual bool eventFilter(QObject* watched, QEvent* e);
+ virtual bool eventFilter(TQObject* watched, TQEvent* e);
signals:
- void openFile(const QString&);
+ void openFile(const TQString&);
- void splitterResized(KoDetailsPaneBase* sender, const QValueList<int>& sizes);
+ void splitterResized(KoDetailsPaneBase* sender, const TQValueList<int>& sizes);
public slots:
- void resizeSplitter(KoDetailsPaneBase* sender, const QValueList<int>& sizes);
+ void resizeSplitter(KoDetailsPaneBase* sender, const TQValueList<int>& sizes);
protected slots:
- void selectionChanged(QListViewItem* item);
+ void selectionChanged(TQListViewItem* item);
void openFile();
- void openFile(QListViewItem* item);
+ void openFile(TQListViewItem* item);
void previewResult(KIO::Job* job);
- void updatePreview(const KFileItem* fileItem, const QPixmap& preview);
+ void updatePreview(const KFileItem* fileItem, const TQPixmap& preview);
void changePalette();
@@ -40,46 +40,47 @@ class KoTemplatesPanePrivate;
/**
* This widget is the right-side part of the template opening widget.
- * The parent widget is initial widget in the document space of each KOffice component.
+ * The tqparent widget is initial widget in the document space of each KOffice component.
* This widget shows a list of templates and can show their details or open it.
*/
@@ -40,46 +40,47 @@ class KoTemplatesPanePrivate;
/**
* Constructor.
- * @param parent the parent widget
+ * @param tqparent the tqparent widget
* @param instance the instance object for the app
* @param group the group of templates this widget will show.
@@ -90,38 +91,39 @@ class KoTemplatesPane : public KoDetailsPaneBase
/**
* This widget is the recent doc part of the template opening widget.
- * The parent widget is initial widget in the document space of each KOffice component.
+ * The tqparent widget is initial widget in the document space of each KOffice component.
* This widget shows a list of recent documents and can show their details or open it.
*/
@@ -90,38 +91,39 @@ class KoTemplatesPane : public KoDetailsPaneBase
/**
* Constructor.
- * @param parent the parent widget
+ * @param tqparent the tqparent widget
* @param instance the instance object for the app
*/